Crate interstice_abi

Crate interstice_abi 

Re-exports

pub use interstice_abi_macros;

Modules

key_code

Structs

AudioStreamConfig
BeginRenderPass
BindGroupEntry
BindGroupLayoutEntry
BlendComponent
BlendState
BufferUsage
CallQueryRequest
CallReducerRequest
ClearTableRequest
ColorTargetState
ColorWrites
CopyBufferToBuffer
CopyBufferToTexture
CopyRequest
CopyTextureToBuffer
CreateBindGroup
CreateBindGroupLayout
CreateBuffer
CreateComputePipeline
CreateDirRequest
CreatePipelineLayout
CreateRenderPipeline
CreateShaderModule
CreateTexture
CreateTextureView
DeleteRowRequest
DepthBiasState
DepthStencilState
DeterministicRandomRequest
DirEntry
Draw
DrawIndexed
Field
FieldDef
FileMetadata
FragmentState
IndexSchema
InsertRowRequest
ListDirRequest
LogRequest
MetadataRequest
ModuleDependency
ModuleSchema
MultisampleState
NodeDependency
NodeSchema
PrimitiveState
QuerySchema
Declared read access for a query (same ReducerTableRef rules as reducer reads).
RawQueryContext
RawReducerContext
ReadFileRequest
ReducerSchema
ReducerTableRef
Declared table access for a reducer: NodeSelection + ModuleSelection + table_name. Use ModuleSelection::Current for the module that contains the reducer (no embedded crate name); the runtime matches that against the active call frame / host-call ModuleSelection, like table scans.
RemoveDirRequest
RemoveFileRequest
RenameRequest
RenderPassColorAttachment
RenderPassDepthStencilAttachment
ReplicatedTableSchema
Row
ScheduleRequest
SetIndexBuffer
SetVertexBuffer
ShaderStage
StencilFaceState
StencilState
SubscriptionSchema
TableGetByPrimaryKeyRequest
TableIndexScanRequest
TableScanRequest
TableSchema
TextureUsage
TimeRequest
UpdateRowRequest
Version
VertexAttribute
VertexBufferLayout
VertexState
WriteBuffer
WriteFileRequest
WriteTexture

Enums

AudioCall
AudioResponse
Authority
BindingResource
BindingType
BlendFactor
BlendOperation
CallQueryResponse
CallReducerResponse
ClearTableResponse
CompareFunction
CopyResponse
CreateDirResponse
CullMode
DeleteRowResponse
DeterministicRandomResponse
ElementState
FileCall
FileEvent
FileType
FrontFace
GpuCall
GpuResponse
HostCall
IndexFormat
IndexKey
IndexQuery
IndexType
InputEvent
InsertRowResponse
Ok(None) = row was inserted unchanged (no auto-inc fields); caller should use the row it already has. Ok(Some(row)) = auto-inc fields were filled in; caller must use the returned row. This avoids serialising + deserialising the full row on the hot path for the common non-auto-inc case.
IntersticeAbiError
IntersticeType
IntersticeTypeDef
IntersticeValue
ListDirResponse
LoadOp
MetadataResponse
ModuleCall
ModuleCallResponse
ModuleEvent
ModuleSelection
ModuleVisibility
NodeSelection
PersistenceKind
PhysicalKey
PrimitiveTopology
ReadFileResponse
RemoveDirResponse
RemoveFileResponse
RenameResponse
ScheduleResponse
StencilOperation
StoreOp
SubscriptionEventSchema
TableGetByPrimaryKeyResponse
TableIndexScanResponse
TableScanResponse
TableVisibility
TextureDimension
TextureFormat
TextureSampleType
TextureViewDimension
TimeResponse
UpdateRowResponse
VertexFormat
VertexStepMode
WriteFileResponse

Constants

ABI_VERSION

Functions

decode
encode
get_query_wrapper_name
get_reducer_wrapper_name
pack_ptr_len
unpack_ptr_len
validate_value
validate_value_detailed

Type Aliases

GpuId