pub struct ReducerTableRef {
pub node_selection: NodeSelection,
pub module_selection: ModuleSelection,
pub table_name: String,
}Expand description
Declared table access for a reducer: NodeSelection + ModuleSelection + table_name.
Use ModuleSelection::Current for the module that contains the reducer (no embedded crate name);
the runtime matches that against the active call frame / host-call ModuleSelection, like table scans.
Fields
node_selection: NodeSelectionmodule_selection: ModuleSelectiontable_name: StringTrait Implementations
Sourceimpl Clone for ReducerTableRef
impl Clone for ReducerTableRef
Sourcefn clone(&self) -> ReducerTableRef
fn clone(&self) -> ReducerTableRef
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReducerTableRef
impl Debug for ReducerTableRef
Sourceimpl<'de> Deserialize<'de> for ReducerTableRef
impl<'de> Deserialize<'de> for ReducerTableRef
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ReducerTableRef
Sourceimpl Hash for ReducerTableRef
impl Hash for ReducerTableRef
Sourceimpl Ord for ReducerTableRef
impl Ord for ReducerTableRef
Sourcefn cmp(&self, other: &ReducerTableRef) -> Ordering
fn cmp(&self, other: &ReducerTableRef) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ReducerTableRef
impl PartialEq for ReducerTableRef
Sourcefn eq(&self, other: &ReducerTableRef) -> bool
fn eq(&self, other: &ReducerTableRef) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ReducerTableRef
impl PartialOrd for ReducerTableRef
Sourceimpl Serialize for ReducerTableRef
impl Serialize for ReducerTableRef
impl StructuralPartialEq for ReducerTableRef