pub struct StencilState {
pub front: StencilFaceState,
pub back: StencilFaceState,
pub read_mask: u32,
pub write_mask: u32,
}Fields
front: StencilFaceStateFront face mode.
back: StencilFaceStateBack face mode.
read_mask: u32Stencil values are AND’d with this mask when reading and writing from the stencil buffer. Only low 8 bits are used.
write_mask: u32Stencil values are AND’d with this mask when writing to the stencil buffer. Only low 8 bits are used.